{#
    basic/globaltoc.html
    ~~~~~~~~~~~~~~~~~~~~

    Sphinx sidebar template: global table of contents.

    :copyright: Copyright 2007-2020 by the Sphinx team, see AUTHORS.
    :license: BSD, see LICENSE for details.
#}
<div class="sidebar-block">
  <h3><a href="{{ pathto(master_doc)|e }}">{{ _('Table of Contents') }}</a></h3>
  <div class="toctree-wrapper">
  {{ toctree(includehidden=theme_globaltoc_includehidden, collapse=theme_globaltoc_collapse) }}
  </div>
</div>